/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.app.view.admin.ResetPasswordViewer");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("com.ibm.rational.report.web.core.client.internal.UserClient");
dojo.require("com.ibm.rational.report.web.core.app.internal.MessageFormatter");
dojo.require("com.ibm.rational.report.web.core.app.internal.Util");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.view.admin", "Messages");

var CommonMessages	    	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");
var CoreAdminMessages		= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.view.admin", "Messages");
var UserClient				= com.ibm.rational.report.web.core.client.internal.UserClient;
var MessageFormatter		= com.ibm.rational.report.web.core.app.internal.MessageFormatter;
var Util					= com.ibm.rational.report.web.core.app.internal.Util;
var ServiceResponseHandler	= com.ibm.team.repository.web.transport.ServiceResponseHandler;

/**
 * Displays the Reset Password view.
 */
dojo.declare(
	"com.ibm.rational.report.web.core.app.view.admin.ResetPasswordViewer",
	[dijit._Widget, dijit._Templated], {
	
	templatePath: dojo.moduleUrl("com.ibm.rational.report.web.core", "app/view/admin/templates/ResetPasswordViewer.html"),
	
	constructor: function(args) {
		this._controller = args.controller;
		this._userName = args.userName;
		this._editUserProfile = args.editUserProfile;
	},
	
	postCreate: function() {
		Util.removeChildren(this.pageTitle);
		this.pageTitle.appendChild(document.createTextNode(CoreAdminMessages.RESET_PASSWORD_VIEWER_PAGE_TITLE));
		
		Util.removeChildren(this.resetButton);
		this.resetButton.appendChild(document.createTextNode(CoreAdminMessages.RESET_PASSWORD_VIEWER_RESET_BUTTON_LABEL));
		
		Util.removeChildren(this.closeButton);
		this.closeButton.appendChild(document.createTextNode(CommonMessages.CLOSE_BUTTON_LABEL));
		
		Util.removeChildren(this.resetUserIdLabel);
		this.resetUserIdLabel.appendChild(document.createTextNode(CoreAdminMessages.RESET_PASSWORD_VIEWER_USERID_LABEL));
		
		Util.removeChildren(this.resetUserFirstNameLabel);
		this.resetUserFirstNameLabel.appendChild(document.createTextNode(CoreAdminMessages.RESET_PASSWORD_VIEWER_FIRST_NAME_LABEL));
		
		Util.removeChildren(this.resetUserLastNameLabel);
		this.resetUserLastNameLabel.appendChild(document.createTextNode(CoreAdminMessages.RESET_PASSWORD_VIEWER_LAST_NAME_LABEL));
		
		Util.removeChildren(this.resetUserScreenNameLabel);
		this.resetUserScreenNameLabel.appendChild(document.createTextNode(CoreAdminMessages.RESET_PASSWORD_VIEWER_SCREEN_NAME_LABEL));
		
		Util.removeChildren(this.resetUserEmailLabel);
		this.resetUserEmailLabel.appendChild(document.createTextNode(CoreAdminMessages.RESET_PASSWORD_VIEWER_EMAIL_ADDRESS_LABEL));
		
		Util.removeChildren(this.emailNotificationLabel);
		this.emailNotificationLabel.appendChild(document.createTextNode(CoreAdminMessages.RESET_PASSWORD_VIEWER_EMAIL_NOTIFICATION_LABEL));
		
		this._msgFormatter = new MessageFormatter(this.messageArea);
		this._adminUser = "";
		this._loginUser = "";
		
		var self = this;
		
		var responseHandler = new ServiceResponseHandler(
			this,
			"_displayUserAttribute",
			"_getUserAttributesError");
		UserClient.getUserAttributes(responseHandler, {name: this._userName});
		
		var self = this;
		
		var responseHandler = new ServiceResponseHandler(
			this,
			"_gotAdminUser",
			"_gotAdminUserError");
		UserClient.getAdminUser(responseHandler);
		
		var responseHandler = new ServiceResponseHandler(
			this,
			"_gotUser",
			"_gotUserError");
		UserClient.getAuthenticatedUser(responseHandler);
	
		dojo.connect(this.resetButton, "onclick",
			function(e) {
				e.preventDefault();
				self._resetPassword();
			}
		);
		
		dojo.connect(this.closeButton, "onclick",
			function(e) {
				e.preventDefault();
				self._exitPage();
			}
		);
	},
	
	_gotAdminUser: function(result) {
	    this._adminUser = result.name;
	},
	
	_gotAdminUserError: function(result) {
	    this._adminUser = "";
	},
	
	_gotUser: function(result) {
	    this._loginUser = result.name;
	},

	_gotUserError: function(result) {
	    this._loginUser = "";
	},
	
	_displayUserAttribute: function(userAttr) {
		this.resetUserId.innerHTML = userAttr.name;
		this.resetUserFirstName.innerHTML = userAttr.firstName;
		this.resetUserLastName.innerHTML = userAttr.lastName;
	   	this.resetUserScreenName.innerHTML = userAttr.screenName;	    	    	    
	    this.resetUserEmail.innerHTML = userAttr.email;
	},
	
	_getUserAttributesError: function(error) {
		var msg = dojo.string.subsitute(ServiceabilityMessages.FAILED_TO_RETRIEVE_USER_PROFILE, [this._userName]);
		this._msgFormatter.displayErrorMessage(msg, error);
	},
	
	_randomPassword: function(length) { 
  		var chars = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890";
  		var password = "";
  		for(var len=0; len<length; len++)
  		{
    		var i = Math.floor(Math.random() * 62);
    		password += chars.charAt(i);
  		}
  		return password;
	},

	_resetPassword : function() {
		Util.removeChildren(this.messageArea);
		var password = this._randomPassword(5);
		var responseHandler = new ServiceResponseHandler(
			this,
			"_exitPage",
			"_postResetPasswordError");
		var args = {
			name: dojo.trim(this._userName),
			password: dojo.string.trim(password)
		};
		UserClient.postUpdateUserAttributes(responseHandler, args);
	},
	
	_postResetPasswordError: function(error) {
		var msg = dojo.string.subsitute(CoreAdminMessages.FAILED_TO_RESET_PASSWORD, [this._userName]);
		this._msgFormatter.displayErrorMessage(msg, error);
	},
	
	_exitPage: function() {
	    if (typeof this._editUserProfile != "undefined") {
			this.controller.clearMainContent(); 
		}
		else {
			this.controller.manageUsers(); 			
		}		
	}
	
});

})();